@@ -51,8 +51,11 @@ package com.openexchange.push.malpoll;
 
 import java.text.MessageFormat;
 import java.util.Iterator;
+import java.util.Map.Entry;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.push.PushException;
 import com.openexchange.push.PushListener;
 import com.openexchange.push.malpoll.services.MALPollServiceRegistry;
@@ -66,6 +69,8 @@ import com.openexchange.tools.Collections;
  */
 public final class MALPollPushListenerRegistry {
 
+    private static final Log LOG = LogFactory.getLog(MALPollPushListenerRegistry.class);
+
     private static final MALPollPushListenerRegistry instance = new MALPollPushListenerRegistry();
 
     /**
@@ -164,21 +169,39 @@ public final class MALPollPushListenerRegistry {
         return removeListener(SimpleKey.valueOf(contextId, userId));
     }
 
+    /**
+     * Purges all listeners and their data.
+     * 
+     * @return <code>true</code> on success; otherwise <code>false</code>
+     */
+    public boolean purgeAllPushListener() {
+        for (final Iterator<Entry<MALPollPushListenerRegistry.SimpleKey, MALPollPushListener>> iterator = map.entrySet().iterator(); iterator.hasNext();) {
+            final Entry<MALPollPushListenerRegistry.SimpleKey, MALPollPushListener> entry = iterator.next();
+            final MALPollPushListener listener = entry.getValue();
+            if (null != listener) {
+                listener.close();
+            }
+            final SimpleKey key = entry.getKey();
+            try {
+                MALPollDBUtility.dropMailIDs(key.cid, key.user);
+            } catch (final PushException e) {
+                LOG.error("DB tables could not be cleansed for removed push listener. User=" + key.user + ", context=" + key.cid, e);
+            }
+        }
+        return true;
+    }
+
     private boolean removeListener(final SimpleKey key) {
         final MALPollPushListener listener = map.remove(key);
         if (null != listener) {
             listener.close();
-            try {
-                MALPollDBUtility.dropMailIDs(key.cid, key.user, MALPollPushListener.getAccountId(), MALPollPushListener.getFolder());
-            } catch (final PushException e) {
-                org.apache.commons.logging.LogFactory.getLog(MALPollPushListenerRegistry.class).error(
-                    new StringBuilder("DB tables could not be cleansed for removed push listener. User=").append(key.user).append(
-                        ", context=").append(key.cid).toString(),
-                    e);
-            }
-            return true;
         }
-        return false;
+        try {
+            MALPollDBUtility.dropMailIDs(key.cid, key.user);
+        } catch (final PushException e) {
+            LOG.error("DB tables could not be cleansed for removed push listener. User=" + key.user + ", context=" + key.cid, e);
+        }
+        return true;
     }
 
     /**
